ConsensusConstants

Struct ConsensusConstants 

pub struct ConsensusConstants {
Show 13 fields pub block_confirmation_depth: BlockNumber, pub shard_confirmation_depth: BlockNumber, pub block_authoring_delay: SlotNumber, pub pot: PotConsensusConstants, pub retarget_interval: BlockNumber, pub slot_probability: (u64, u64), pub slot_duration: SlotDuration, pub recent_segments: HistorySize, pub recent_history_fraction: (HistorySize, HistorySize), pub min_sector_lifetime: HistorySize, pub max_block_timestamp_drift: BlockTimestamp, pub shard_rotation_interval: BlockNumber, pub shard_rotation_delay: BlockNumber,
}
Consensus constants

Fields

block_confirmation_depth: BlockNumber

Depth after which a block enters the recorded history.

This is from the perspective of the individual shard, with additional confirmation on the beacon chain required for intermediate and leaf shards (see shard_confirmation_depth).

shard_confirmation_depth: BlockNumber

Depth on the beacon chain in addition to block_confirmation_depth after intermediate or leaf shard information on the beacon chain is confirmed and corresponding segment roots become a part of the super segment.

This is separate from the block confirmation on the corresponding shard itself, which happens much sooner (see block_confirmation_depth), but can’t be immediately trusted by the beacon chain.

block_authoring_delay: SlotNumber

Number of slots between slot arrival and when the corresponding block can be produced

pot: PotConsensusConstants

Proof-of-time consensus constants

retarget_interval: BlockNumber

Period of time in blocks after which the solution range is adjusted

slot_probability: (u64, u64)

Slot probability

slot_duration: SlotDuration

The slot duration in milliseconds

recent_segments: HistorySize

Number of latest archived segments that are considered “recent history”

recent_history_fraction: (HistorySize, HistorySize)

Fraction of pieces from the “recent history” (recent_segments) in each sector

min_sector_lifetime: HistorySize

Minimum lifetime of a plotted sector, measured in archived segments

max_block_timestamp_drift: BlockTimestamp

Max block timestamp drift allowed

shard_rotation_interval: BlockNumber

Number of beacon chain blocks between shard rotations.

Every this number of beacon chain blocks PoT entropy is taken to calculate the next shard assignment.

shard_rotation_delay: BlockNumber

Delay in beacon chain blocks for the next shard rotation.

Delay after shard assignment is revealed before it actually takes effect (essentially the amount of time for a node to sync the corresponding shard).